@@ -1,4 +1,4 @@
-__version__ = "1.0.75"
+__version__ = "1.0.80"
 
 import kappadata.caching
 import kappadata.common
@@ -19,6 +19,9 @@ from .collators.base.kd_compose_collator import KDComposeCollator
 from .collators.base.kd_single_collator import KDSingleCollator
 from .collators.kd_mix_collator import KDMixCollator
 from .collators.pad_sequences_collator import PadSequencesCollator
+# common
+from .common.transforms.norm.kd_cifar10_norm import KDCifar10Norm
+from .common.transforms.norm.kd_image_net_norm import KDImageNetNorm
 # copying
 from .copying import (
     copy_imagefolder_from_global_to_local,
@@ -49,8 +52,6 @@ from .transforms.kd_random_horizontal_flip import KDRandomHorizontalFlip
 from .transforms.kd_random_resized_crop import KDRandomResizedCrop
 from .transforms.kd_random_solarize import KDRandomSolarize
 # transforms norm
-from .transforms.norm.kd_cifar10_norm import KDCifar10Norm
-from .transforms.norm.kd_image_net_norm import KDImageNetNorm
 from .transforms.norm.kd_image_norm import KDImageNorm
 from .transforms.norm.kd_image_range_norm import KDImageRangeNorm
 from .transforms.patchify_image import PatchifyImage
@@ -58,6 +59,13 @@ from .transforms.patchwise_random_rotation import PatchwiseRandomRotation
 from .transforms.patchwise_shuffle import PatchwiseShuffle
 from .transforms.save_state_to_context_transform import SaveStateToContextTransform
 from .transforms.unpatchify_image import UnpatchifyImage
+# utils
+from .utils.is_deterministic_transform import (
+    is_deterministic_transform,
+    IsDeterministicTransformResult,
+    has_stochastic_transform_with_seed,
+    is_randomly_seeded_transform,
+)
 # wrappers.dataset_wrappers
 from .wrappers.dataset_wrappers.class_filter_wrapper import ClassFilterWrapper
 from .wrappers.dataset_wrappers.oversampling_wrapper import OversamplingWrapper
@@ -66,14 +74,9 @@ from .wrappers.dataset_wrappers.repeat_wrapper import RepeatWrapper
 from .wrappers.dataset_wrappers.shuffle_wrapper import ShuffleWrapper
 from .wrappers.dataset_wrappers.subset_wrapper import SubsetWrapper
 from .wrappers.mode_wrapper import ModeWrapper
-from .wrappers.torch_wrapper import TorchWrapper
 # wrappers.sample_wrappers
 from .wrappers.sample_wrappers.label_smoothing_wrapper import LabelSmoothingWrapper
+from .wrappers.sample_wrappers.multi_view_wrapper import MultiViewWrapper
 from .wrappers.sample_wrappers.one_hot_wrapper import OneHotWrapper
-# utils
-from .utils.is_deterministic_transform import (
-    is_deterministic_transform,
-    IsDeterministicTransformResult,
-    has_stochastic_transform_with_seed,
-    is_randomly_seeded_transform,
-)
\ No newline at end of file
+from .wrappers.sample_wrappers.x_transform_wrapper import XTransformWrapper
+from .wrappers.torch_wrapper import TorchWrapper
