@@ -29,9 +29,13 @@ class ModeWrapper(KDDataset):
     def has_item(mode, item):
         return item in mode.split(" ")
 
+    @staticmethod
+    def get_item_index(mode, item):
+        return mode.split(" ").index(item)
+
     @staticmethod
     def get_item(mode, item, batch):
-        idx = mode.split(" ").index(item)
+        idx = ModeWrapper.get_item_index(mode=mode, item=item)
         return batch[idx]
 
     @staticmethod
